==> packageinstaller-pkglist_0.3.29.tar.xz: packageinstaller-pkglist/Nepalese.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Nepalese
</name>

<description>
   <am>Nepalese dictionary for hunspell</am>
   <ar>Nepalese dictionary for hunspell</ar>
   <be>Nepalese dictionary for hunspell</be>
   <bg>Nepalese dictionary for hunspell</bg>
   <bn>Nepalese dictionary for hunspell</bn>
   <ca>Nepalese dictionary for hunspell</ca>
   <cs>Nepalese dictionary for hunspell</cs>
   <da>Nepalese dictionary for hunspell</da>
   <de>Nepalese dictionary for hunspell</de>
   <el>Λεξικό Νεπάλ για hunspell</el>
   <en>Nepalese dictionary for hunspell</en>
   <es_ES>Nepalese dictionary for hunspell</es_ES>
   <es>Diccionario Nepalí para hunspell</es>
   <et>Nepalese dictionary for hunspell</et>
   <eu>Nepalese dictionary for hunspell</eu>
   <fa>Nepalese dictionary for hunspell</fa>
   <fil_PH>Nepalese dictionary for hunspell</fil_PH>
   <fi>Nepalese dictionary for hunspell</fi>
   <fr_BE>Nepalese dictionary for hunspell</fr_BE>
   <fr>Nepalese dictionary for hunspell</fr>
   <gl_ES>Nepalese dictionary for hunspell</gl_ES>
   <he_IL>Nepalese dictionary for hunspell</he_IL>
   <hi>Nepalese dictionary for hunspell</hi>
   <hr>Nepalese dictionary for hunspell</hr>
   <hu>Nepalese dictionary for hunspell</hu>
   <id>Nepalese dictionary for hunspell</id>
   <is>Nepalese dictionary for hunspell</is>
   <it>Nepalese dictionary for hunspell</it>
   <ja>Hunspell 用ネパール語辞書</ja>
   <kk>Nepalese dictionary for hunspell</kk>
   <ko>Nepalese dictionary for hunspell</ko>
   <lt>Nepalese dictionary for hunspell</lt>
   <mk>Nepalese dictionary for hunspell</mk>
   <mr>Nepalese dictionary for hunspell</mr>
   <nb_NO>Nepalese dictionary for hunspell</nb_NO>
   <nb>Nepalese dictionary for hunspell</nb>
   <nl_BE>Nepalese dictionary for hunspell</nl_BE>
   <nl>Nepalese dictionary for hunspell</nl>
   <pl>Nepalese dictionary for hunspell</pl>
   <pt_BR>Nepalese dictionary for hunspell</pt_BR>
   <pt>Nepalese dictionary for hunspell</pt>
   <ro>Nepalese dictionary for hunspell</ro>
   <ru>Nepalese dictionary for hunspell</ru>
   <sk>Nepalese dictionary for hunspell</sk>
   <sl>Nepalese dictionary for hunspell</sl>
   <sq>Nepalese dictionary for hunspell</sq>
   <sr>Nepalese dictionary for hunspell</sr>
   <sv>Nepalese dictionary for hunspell</sv>
   <th>Nepalese dictionary for hunspell</th>
   <tr>Nepalese dictionary for hunspell</tr>
   <uk>Nepalese dictionary for hunspell</uk>
   <vi>Nepalese dictionary for hunspell</vi>
   <zh_CN>Nepalese dictionary for hunspell</zh_CN>
   <zh_HK>Nepalese dictionary for hunspell</zh_HK>
   <zh_TW>Nepalese dictionary for hunspell</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
hunspell-ne
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
hunspell-ne
</uninstall_package_names>

</app>

==> packageinstaller-pkglist_0.3.32.tar.xz: packageinstaller-pkglist/Nepalese.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Nepalese
</name>

<description>
   <am>Nepalese dictionary for hunspell</am>
   <ar>Nepalese dictionary for hunspell</ar>
   <be>Nepalese dictionary for hunspell</be>
   <bg>Nepalese dictionary for hunspell</bg>
   <bn>Nepalese dictionary for hunspell</bn>
   <ca>Nepalese dictionary for hunspell</ca>
   <cs>Nepalese dictionary for hunspell</cs>
   <da>Nepalese dictionary for hunspell</da>
   <de>Nepali Wörterbuch für “Hunspell”</de>
   <el>Λεξικό Νεπάλ για hunspell</el>
   <en>Nepalese dictionary for hunspell</en>
   <es_ES>Diccionario Nepalí para hunspell</es_ES>
   <es>Diccionario Nepalí para hunspell</es>
   <et>Nepalese dictionary for hunspell</et>
   <eu>Nepalese dictionary for hunspell</eu>
   <fa>Nepalese dictionary for hunspell</fa>
   <fil_PH>Nepalese dictionary for hunspell</fil_PH>
   <fi>Nepalese dictionary for hunspell</fi>
   <fr_BE>Nepalese dictionary for hunspell</fr_BE>
   <fr>Népalais dictionnaire pour hunspell</fr>
   <gl_ES>Nepalese dictionary for hunspell</gl_ES>
   <gu>Nepalese dictionary for hunspell</gu>
   <he_IL>Nepalese dictionary for hunspell</he_IL>
   <hi>Nepalese dictionary for hunspell</hi>
   <hr>Nepalese dictionary for hunspell</hr>
   <hu>Nepalese dictionary for hunspell</hu>
   <id>Nepalese dictionary for hunspell</id>
   <is>Nepalese dictionary for hunspell</is>
   <it>Dizionario nepalese per hunspell</it>
   <ja>Hunspell 用ネパール語辞書</ja>
   <kk>Nepalese dictionary for hunspell</kk>
   <ko>Nepalese dictionary for hunspell</ko>
   <lt>Nepalese dictionary for hunspell</lt>
   <mk>Nepalese dictionary for hunspell</mk>
   <mr>Nepalese dictionary for hunspell</mr>
   <nb_NO>Nepalese dictionary for hunspell</nb_NO>
   <nb>Nepalesisk ordliste for hunspell</nb>
   <nl_BE>Nepalese dictionary for hunspell</nl_BE>
   <nl>Nepalese dictionary for hunspell</nl>
   <pl>Nepalese dictionary for hunspell</pl>
   <pt_BR>Dicionário Nepali para o hunspell (corretor ortográfico e analisador morfológico)</pt_BR>
   <pt>Dicionário Nepalês para hunspell</pt>
   <ro>Nepalese dictionary for hunspell</ro>
   <ru>Nepalese dictionary for hunspell</ru>
   <sk>Nepalese dictionary for hunspell</sk>
   <sl>Nepalese dictionary for hunspell</sl>
   <sq>Nepalese dictionary for hunspell</sq>
   <sr>Nepalese dictionary for hunspell</sr>
   <sv>Nepalesisk ordbok för hunspell</sv>
   <th>Nepalese dictionary for hunspell</th>
   <tr>Nepalese dictionary for hunspell</tr>
   <uk>Nepalese dictionary for hunspell</uk>
   <vi>Nepalese dictionary for hunspell</vi>
   <zh_CN>Nepalese dictionary for hunspell</zh_CN>
   <zh_HK>Nepalese dictionary for hunspell</zh_HK>
   <zh_TW>Nepalese dictionary for hunspell</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
hunspell-ne
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
hunspell-ne
</uninstall_package_names>

</app>
